@@ -1,23 +1,24 @@
-import hmac
-import pickle
 import importlib
 import inspect
 import logging
+import pickle
 from typing import Any, Callable, Dict, List, Optional, Type, Union
 
-import orjson
-import shortuuid
-from bs4 import BeautifulSoup
-from bs4.element import Tag
-from bs4.formatter import HTMLFormatter
-from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 from django.db.models import Model
 from django.template.response import TemplateResponse
 from django.utils.safestring import mark_safe
 from django.views.generic.base import TemplateView
 
+import orjson
+import shortuuid
+from bs4 import BeautifulSoup
+from bs4.element import Tag
+from bs4.formatter import HTMLFormatter
+
 from . import serializer
+from .settings import get_setting
+from .utils import generate_checksum
 
 
 logger = logging.getLogger(__name__)
@@ -102,12 +103,7 @@ class UnicornTemplateResponse(TemplateResponse):
 
         content = response.content.decode("utf-8")
 
-        checksum = hmac.new(
-            str.encode(settings.SECRET_KEY),
-            str.encode(str(self.frontend_context_variables)),
-            digestmod="sha256",
-        ).hexdigest()
-        checksum = shortuuid.uuid(checksum)[:8]
+        checksum = generate_checksum(str.encode(str(self.frontend_context_variables)))
 
         soup = BeautifulSoup(content, features="html.parser")
         root_element = UnicornTemplateResponse._get_root_element(soup)
@@ -626,12 +622,20 @@ class UnicornView(TemplateView):
             # Use conventions to find the component class
             class_name = convert_to_camel_case(component_name)
             class_name = f"{class_name}View"
-
             module_name = convert_to_snake_case(component_name)
-            module_name = f"unicorn.components.{module_name}"
-            locations.append((class_name, module_name))
 
-        # TODO: django.conf setting that has locations for where to look for components
+            unicorn_apps = get_setting("APPS", ["unicorn"])
+
+            assert (
+                isinstance(unicorn_apps, list)
+                or isinstance(unicorn_apps, tuple)
+                or isinstance(unicorn_apps, set)
+            ), "APPS is expected to be a list, tuple or set"
+
+            for app in unicorn_apps:
+                app_module_name = f"{app}.components.{module_name}"
+                locations.append((class_name, app_module_name))
+
         # TODO: django.conf setting bool that defines whether to look in all installed apps for components
 
         # Store the last exception that got raised while looking for a component in case it is useful context
