@@ -26,10 +26,11 @@ export class Element {
 
     this.model = {};
     this.poll = {};
+    this.loading = {};
     this.actions = [];
     this.db = {};
     this.field = {};
-
+    this.target = null;
     this.key = null;
     this.errors = [];
 
@@ -74,6 +75,20 @@ export class Element {
         if (pollArgs.length > 0) {
           this.poll.timing = parseInt(pollArgs[0], 10) || 2000;
         }
+      } else if (attribute.isLoading) {
+        if (attribute.modifiers.attr) {
+          this.loading.attr = attribute.value;
+        } else if (attribute.modifiers.class && attribute.modifiers.remove) {
+          this.loading.removeClass = attribute.value;
+        } else if (attribute.modifiers.class) {
+          this.loading.class = attribute.value;
+        } else if (attribute.modifiers.remove) {
+          this.loading.hide = true;
+        } else {
+          this.loading.show = true;
+        }
+      } else if (attribute.isTarget) {
+        this.target = attribute.value;
       } else if (attribute.eventType) {
         const action = {};
         action.name = attribute.value;
@@ -108,7 +123,7 @@ export class Element {
     }
 
     // Look in parent elements if the db.pk or db.name is missing
-    if (this.isUnicorn && !isEmpty(this.field)) {
+    if (this.isUnicorn && hasValue(this.field)) {
       const dbAttrs = ["pk", "name"];
       let elToCheck = this;
 
@@ -140,7 +155,14 @@ export class Element {
         }
 
         if (elToCheck.isUnicorn && hasValue(elToCheck.model.name)) {
-          this.model.name = elToCheck.model.name;
+          if (hasValue(this.field) && isEmpty(this.db)) {
+            // Handle a model + field that is not a db
+            this.model = this.field; // Make sure to keep all modifiers from the field for the model
+            this.model.name = `${elToCheck.model.name}.${this.field.name}`;
+            this.field = {};
+          } else {
+            this.model.name = elToCheck.model.name;
+          }
         }
 
         elToCheck = elToCheck.parent;
@@ -155,6 +177,20 @@ export class Element {
     this.el.focus();
   }
 
+  /**
+   * Hide the element.
+   */
+  hide() {
+    this.el.hidden = "hidden";
+  }
+
+  /**
+   * Show the element.
+   */
+  show() {
+    this.el.hidden = null;
+  }
+
   /**
    * A key that takes into consideration the db name and pk.
    */
